Factory helpers
===============

Convenience helpers for one-shot chart creation from raw data.

.. autofunction:: textcharts.bar_chart.from_data
   :no-index:

.. autofunction:: textcharts.box_plot.from_series
   :no-index:

.. autofunction:: textcharts.cdf_chart.from_series
   :no-index:

.. autofunction:: textcharts.comparison_bar.from_data
   :no-index:

.. autofunction:: textcharts.diverging_bar.from_data
   :no-index:

.. autofunction:: textcharts.heatmap.from_matrix
   :no-index:

.. autofunction:: textcharts.histogram.from_data
   :no-index:

.. autofunction:: textcharts.line_chart.from_points
   :no-index:

.. autofunction:: textcharts.normalized_speedup.from_ratios
   :no-index:

.. autofunction:: textcharts.percentile_ladder.from_series
   :no-index:

.. autofunction:: textcharts.rank_table.from_matrix
   :no-index:

.. autofunction:: textcharts.scatter_plot.from_points
   :no-index:

.. autofunction:: textcharts.sparkline_table.from_data
   :no-index:

.. autofunction:: textcharts.stacked_bar.from_data
   :no-index:
